Skip to contents

This package provides a means to quantify an individual's migratory status within a given year. This packages allows the user to determine an individual's migratory status within geographical and environmental space.