between_emd.Rd
Calculates the between seasonal range Earth-mover's distance (EMD)
between_emd(t1, t2)
A list of rasters for each interval for a given range.
A second list of raster for each interval for a given range that is being compared with the first list of rasters (t1).
The output is a list of matrices that contain the EMDs for each individual in a given year comparing different intervals.