Skip to contents

Grabs the attributes that you assigned to a list

Usage

check(list, attribute_name)

Arguments

list

The list object that the attribute is being assigned to.

attribute_name

The name of the attribute item created for both list1 and list2 The input for this argument must be a character.

Value

This grabs the attributes that you assigned to the list.