Skip to contents

Creates raster stacks from a environmental covariate layer and home range

Usage

env_raster_stack(env, hrr, attribute = NULL)

Arguments

env

A environmental raster layer

hrr

A home range that the environmental covariate is resampled to.

attribute

A attribute value that the environmental layers should be applied accordingly.

Value

The output is a raster stack that contains the home ranges and the environmental covariate layer.