Skip to contents

Matches the number of intervals between the two seasons selected

Usage

match_intervals(attribute_name, list1, list2, id_col, interval_col)

Arguments

attribute_name

The name of the attribute item created for both list1 and list2 The input for this argument must be a character.

list1

A list object that is the reference for list2

list2

A list object that the length of list2 is being matched to

id_col

This should be the name of assigned to the id column within the attribute table created.

interval_col

This should be the name assigned to the interval column within the attribute_table created.

Value

The output is a list that contains two new list. These two new list have the same individuals and intervals for those individuals.