Skip to contents

Calculates the Earth-Mover's Distance (EMD) within the same range

Usage

within_emd(t)

Arguments

t

List of rasters containing the raster for each period within the

nintervals

The length that the rasters are broken up into by the specified interval.

Value

The output is a list of matrices that contain the within- range EMDs