Matches the number of intervals between the two seasons selected
match_intervals.RdMatches the number of intervals between the two seasons selected
Arguments
- attribute_name
The name of the attribute item created for both
list1andlist2The input for this argument must be a character.- list1
A list object that is the reference for
list2- list2
A list object that the length of
list2is being matched to- id_col
This should be the name of assigned to the id column within the attribute table created.
- interval_col
This should be the name assigned to the interval column within the attribute_table created.